@@ -462,20 +462,20 @@ class MTimeComparator(object):
     """
 
     def __init__(self, filenames, compare_func=None):
-        self.filenames = filenames
         self.compare_func = (os.path.getmtime if compare_func is None
                              else compare_func)
-        self.last_max_mtime = self.get_most_recent_changed()
-
-    def get_most_recent_changed(self):
-        if not self.filenames:
-            return -1
-        return max(self.compare_func(name) for name in self.filenames)
+        self.filenames_mtimes = {
+            filename: self.compare_func(filename) for filename in filenames
+        }
 
     def has_changed(self):
-        last_mtime, self.last_max_mtime = (
-                self.last_max_mtime, self.get_most_recent_changed())
-        return last_mtime < self.last_max_mtime
+        for filename, compare_val in self.filenames_mtimes.items():
+            current_compare_val = self.compare_func(filename)
+            if compare_val != current_compare_val:
+                self.filenames_mtimes[filename] = current_compare_val
+                return True
+
+        return False
 
 
 class MD5Comparator(object):
@@ -582,7 +582,14 @@ class ConfigFacade(object):
         self.callback_chain = watcher.get_reloader()
 
     @classmethod
-    def load(cls, filename, namespace, loader_func, min_interval=0):
+    def load(
+            cls,
+            filename,
+            namespace,
+            loader_func,
+            min_interval=0,
+            comparators=None,
+    ):
         """Create a new :class:`ConfigurationWatcher` and load the initial
         configuration by calling `loader_func`.
 
@@ -597,13 +604,18 @@ class ConfigFacade(object):
         :param min_interval: minimum number of seconds to wait between calls to
                              :func:`os.path.getmtime` to check if a file has
                              been modified.
+        :param comparators: a list of classes which support the
+            :class:`IComparator` interface which are used to determine if a config
+            file has been modified. See ConfigurationWatcher::__init__.
         :returns: a :class:`ConfigFacade`
         """
         watcher = ConfigurationWatcher(
             build_loader_callable(loader_func, filename, namespace=namespace),
             filename,
             min_interval=min_interval,
-            reloader=ReloadCallbackChain(namespace=namespace))
+            reloader=ReloadCallbackChain(namespace=namespace),
+            comparators=comparators,
+        )
         watcher.load_config()
         return cls(watcher)
 
