@@ -32,14 +32,14 @@ class TestRemoveByKeys(object):
 
     def test_no_keys(self):
         keys = []
-        map = dict(enumerate(range(3)))
-        assert_equal(list(map.items()), config.remove_by_keys(map, keys))
+        testMap = dict(enumerate(range(3)))
+        assert_equal(list(testMap.items()), config.remove_by_keys(testMap, keys))
 
     def test_overlap(self):
-        keys = [1, 3, 5 ,7]
-        map = dict(enumerate(range(8)))
-        expected = [(0,0), (2, 2), (4, 4), (6, 6)]
-        assert_equal(expected, config.remove_by_keys(map, keys))
+        keys = [1, 3, 5, 7]
+        testMap = dict(enumerate(range(8)))
+        expected = [(0, 0), (2, 2), (4, 4), (6, 6)]
+        assert_equal(expected, config.remove_by_keys(testMap, keys))
 
 
 class TestConfigMap(object):
@@ -81,9 +81,13 @@ class TestConfigurationNamespace(object):
             self.namespace.register_proxy(mock_proxy)
         assert_equal(self.namespace.get_value_proxies(), proxies)
 
-    @pytest.mark.skipif('PyPy' in platform.python_implementation(), reason="Fails on PyPy")
+    @pytest.mark.skipif(
+        'PyPy' in platform.python_implementation(),
+        reason="Fails on PyPy",
+    )
     def test_get_value_proxies_does_not_contain_out_of_scope_proxies(self):
         assert not self.namespace.get_value_proxies()
+
         def a_scope():
             mock_proxy = mock.create_autospec(proxy.ValueProxy)
             self.namespace.register_proxy(mock_proxy)
@@ -255,12 +259,12 @@ class TestValidateConfig(object):
     def test_validate_single_passes(self):
         staticconf.DictConfiguration({})
         config.validate()
-        _ = staticconf.get_string('one.two')
+        _ = staticconf.get_string('one.two')  # noqa: F841
         staticconf.DictConfiguration({'one.two': 'nice'})
         config.validate()
 
     def test_validate_single_fails(self):
-        _ = staticconf.get_int('one.two')
+        _ = staticconf.get_int('one.two')  # noqa: F841
         assert_raises(errors.ConfigurationError, config.validate)
 
     def test_validate_all_passes(self):
@@ -277,7 +281,7 @@ class TestValidateConfig(object):
 
     def test_validate_all_fails(self):
         name = 'yan'
-        _ = staticconf.get_string('foo', namespace=name)  # flake8: noqa
+        _ = staticconf.get_string('foo', namespace=name)  # noqa: F841
         assert_raises(errors.ConfigurationError,
                       config.validate,
                       all_names=True)
@@ -363,8 +367,12 @@ class TestConfigurationWatcher(object):
         with mock.patch('staticconf.config.time') as self.mock_time:
             with mock.patch('staticconf.config.os.stat') as self.mock_stat:
                 with tempfile.NamedTemporaryFile() as file:
-                    with mock.patch('staticconf.config.os.path') as self.mock_path:
+                    with mock.patch(
+                        'staticconf.config.os.path.getmtime',
+                    ) as self.mock_getmtime:
                         file.flush()
+                        self.mtime = 234
+                        self.mock_getmtime.return_value = self.mtime
                         self.mock_stat.return_value.st_ino = 1
                         self.mock_stat.return_value.st_dev = 2
                         self.filename = file.name
@@ -373,16 +381,18 @@ class TestConfigurationWatcher(object):
                         yield
 
     def test_get_filename_list_from_string(self):
-        self.mock_path.abspath.side_effect = lambda p: p
-        filename = 'thefilename.yaml'
-        filenames = self.watcher.get_filename_list(filename)
-        assert_equal(filenames, [filename])
+        with mock.patch('staticconf.config.os.path.abspath') as mock_path_abspath:
+            mock_path_abspath.side_effect = lambda p: p
+            filename = 'thefilename.yaml'
+            filenames = self.watcher.get_filename_list(filename)
+            assert_equal(filenames, [filename])
 
     def test_get_filename_list_from_list(self):
-        self.mock_path.abspath.side_effect = lambda p: p
-        filenames = ['b', 'g', 'z', 'a']
-        expected = ['a', 'b', 'g', 'z']
-        assert_equal(self.watcher.get_filename_list(filenames), expected)
+        with mock.patch('staticconf.config.os.path.abspath') as mock_path_abspath:
+            mock_path_abspath.side_effect = lambda p: p
+            filenames = ['b', 'g', 'z', 'a']
+            expected = ['a', 'b', 'g', 'z']
+            assert_equal(self.watcher.get_filename_list(filenames), expected)
 
     def test_should_check(self):
         self.watcher.last_check = 123456789
@@ -400,15 +410,13 @@ class TestConfigurationWatcher(object):
         assert self.watcher.should_check
 
     def test_file_modified_not_modified(self):
-        self.watcher.comparators[0].last_max_mtime = mtime = 222
-        self.mock_path.getmtime.return_value = mtime
-        self.mock_time.time.return_value = 123456
+        self.mock_time.time.return_value = 123460
         assert not self.watcher.file_modified()
         assert_equal(self.watcher.last_check, self.mock_time.time.return_value)
 
     def test_file_modified(self):
         self.watcher.comparators[0].last_max_mtime = 123456
-        self.mock_path.getmtime.return_value = 123460
+        self.mock_getmtime.return_value = 123460
 
         assert self.watcher.file_modified()
         assert_equal(self.watcher.last_check, self.mock_time.time.return_value)
@@ -440,30 +448,35 @@ class TestInodeComparator(object):
 
 
 class TestMTimeComparator(object):
-
-    def test_get_most_recent_empty(self):
-        comparator = config.MTimeComparator([])
-        assert comparator.get_most_recent_changed() == -1
-
-    @mock.patch('staticconf.config.os.path.getmtime', autospec=True, side_effect=[0,0,1,2,3])
-    def test_get_most_recent(self, mock_mtime):
-        comparator = config.MTimeComparator(['./one.file', './two.file'])
-        assert comparator.get_most_recent_changed() == 2
-        assert mock_mtime.call_count == 4
-
     @mock.patch('staticconf.config.os.path.getmtime', autospec=True, return_value=1)
     def test_no_change(self, mock_mtime):
         comparator = config.MTimeComparator(['./one.file'])
         assert not comparator.has_changed()
         assert not comparator.has_changed()
 
-    @mock.patch('staticconf.config.os.path.getmtime', autospec=True, side_effect=[0,1,1,2])
+    @mock.patch(
+        'staticconf.config.os.path.getmtime',
+        autospec=True,
+        side_effect=[0, 1, 1, 2],
+    )
     def test_changes(self, mock_mtime):
         comparator = config.MTimeComparator(['./one.file'])
         assert comparator.has_changed()
         assert not comparator.has_changed()
         assert comparator.has_changed()
 
+    @mock.patch(
+        'staticconf.config.os.path.getmtime',
+        autospec=True,
+        side_effect=[1, 2, 1],
+    )
+    def test_change_when_newer_time_before_older_time(self, mock_mtime):
+        comparator = config.MTimeComparator(['./one.file'])
+        # 1 -> 2
+        assert comparator.has_changed()
+        # 2 -> 1 (can happen as a result of a revert)
+        assert comparator.has_changed()
+
 
 class TestMTimeComparatorWithCompareFunc(object):
 
@@ -483,22 +496,12 @@ class TestMTimeComparatorWithCompareFunc(object):
         self._exc_info = sys.exc_info()
 
     def test_logs_error(self):
-        comparator = self._LoggingMTimeComparator(['./not.a.file'])
-        assert comparator.get_most_recent_changed() == -1
+        self._LoggingMTimeComparator(['./not.a.file'])
         assert self._err_filename == "./not.a.file"
         assert all(x is not None for x in self._exc_info)
 
     def test_get_most_recent_empty(self):
-        comparator = self._LoggingMTimeComparator([])
-        assert comparator.get_most_recent_changed() == -1
-        assert self._err_filename is None
-        assert all(x is None for x in self._exc_info)
-
-    @mock.patch('staticconf.config.os.path.getmtime', autospec=True, side_effect=[0,0,1,2,3])
-    def test_get_most_recent(self, mock_mtime):
-        comparator = self._LoggingMTimeComparator(['./one.file', './two.file'])
-        assert comparator.get_most_recent_changed() == 2
-        assert mock_mtime.call_count == 4
+        self._LoggingMTimeComparator([])
         assert self._err_filename is None
         assert all(x is None for x in self._exc_info)
 
@@ -510,7 +513,11 @@ class TestMTimeComparatorWithCompareFunc(object):
         assert self._err_filename is None
         assert all(x is None for x in self._exc_info)
 
-    @mock.patch('staticconf.config.os.path.getmtime', autospec=True, side_effect=[0,1,1,2])
+    @mock.patch(
+        'staticconf.config.os.path.getmtime',
+        autospec=True,
+        side_effect=[0, 1, 1, 2],
+    )
     def test_changes(self, mock_mtime):
         comparator = self._LoggingMTimeComparator(['./one.file'])
         assert comparator.has_changed()
@@ -598,6 +605,29 @@ class TestConfigFacade(object):
         reloader = facade.callback_chain
         assert_equal(reloader, facade.watcher.get_reloader())
 
+    def test_load_passes_comparators_to_configuration_watcher(self):
+        filename, namespace = "filename", "namespace"
+        loader = mock.Mock()
+        comparator = mock.Mock(name='MockComparator')
+
+        with mock.patch(
+            'staticconf.config.ConfigurationWatcher',
+            autospec=True
+        ) as mock_watcher_class:
+            config.ConfigFacade.load(
+                filename,
+                namespace,
+                loader,
+                comparators=[comparator],
+            )
+            mock_watcher_class.assert_called_with(
+                mock.ANY,
+                filename,
+                min_interval=mock.ANY,
+                reloader=mock.ANY,
+                comparators=[comparator],
+            )
+
     def test_add_callback(self):
         name, func = 'name', mock.Mock()
         self.facade.add_callback(name, func)
@@ -644,7 +674,6 @@ class TestConfigFacadeAcceptance(object):
 
     def test_reload_end_to_end(self):
         loader = mock.Mock()
-        callback = mock.Mock()
         facade = staticconf.ConfigFacade.load(
                 self.file.name,
                 self.namespace,
